From aeb44609d8734ac799bdb941addac0fb82f7e549 Mon Sep 17 00:00:00 2001
From: Justin Pryzby <pryzbyj@telsasoft.com>
Date: Wed, 17 Aug 2022 08:49:46 -0500
Subject: [PATCH 19/26] avoid shadow vars: psql/command.c: host

commit 87e0b7422d70ff4fb69612ef7ba3cbee6ed8d2ae
Author: Robert Haas <rhaas@postgresql.org>
Date:   Fri Jul 23 14:56:54 2010 +0000

    Have psql avoid describing local sockets as host names.
---
 src/bin/psql/command.c | 18 +++++++++---------
 1 file changed, 9 insertions(+), 9 deletions(-)

diff --git a/src/bin/psql/command.c b/src/bin/psql/command.c
index a81bd3307b4..09950cac60a 100644
--- a/src/bin/psql/command.c
+++ b/src/bin/psql/command.c
@@ -3551,27 +3551,27 @@ do_connect(enum trivalue reuse_previous_specification,
 			param_is_newly_set(PQhost(o_conn), PQhost(pset.db)) ||
 			param_is_newly_set(PQport(o_conn), PQport(pset.db)))
 		{
-			char	   *host = PQhost(pset.db);
-			char	   *hostaddr = PQhostaddr(pset.db);
+			char	   *dbhost = PQhost(pset.db);
+			char	   *dbhostaddr = PQhostaddr(pset.db);
 
-			if (is_unixsock_path(host))
+			if (is_unixsock_path(dbhost))
 			{
 				/* hostaddr overrides host */
-				if (hostaddr && *hostaddr)
+				if (dbhostaddr && *dbhostaddr)
 					printf(_("You are now connected to database \"%s\" as user \"%s\" on address \"%s\" at port \"%s\".\n"),
-						   PQdb(pset.db), PQuser(pset.db), hostaddr, PQport(pset.db));
+						   PQdb(pset.db), PQuser(pset.db), dbhostaddr, PQport(pset.db));
 				else
 					printf(_("You are now connected to database \"%s\" as user \"%s\" via socket in \"%s\" at port \"%s\".\n"),
-						   PQdb(pset.db), PQuser(pset.db), host, PQport(pset.db));
+						   PQdb(pset.db), PQuser(pset.db), dbhost, PQport(pset.db));
 			}
 			else
 			{
-				if (hostaddr && *hostaddr && strcmp(host, hostaddr) != 0)
+				if (dbhostaddr && *dbhostaddr && strcmp(dbhost, dbhostaddr) != 0)
 					printf(_("You are now connected to database \"%s\" as user \"%s\" on host \"%s\" (address \"%s\") at port \"%s\".\n"),
-						   PQdb(pset.db), PQuser(pset.db), host, hostaddr, PQport(pset.db));
+						   PQdb(pset.db), PQuser(pset.db), dbhost, dbhostaddr, PQport(pset.db));
 				else
 					printf(_("You are now connected to database \"%s\" as user \"%s\" on host \"%s\" at port \"%s\".\n"),
-						   PQdb(pset.db), PQuser(pset.db), host, PQport(pset.db));
+						   PQdb(pset.db), PQuser(pset.db), dbhost, PQport(pset.db));
 			}
 		}
 		else
-- 
2.17.1

